@@ -93,4 +93,4 @@ LDP_RDF_CONTEXT={
 }
 SEND_BACKLINKS=False
 GUARDIAN_AUTO_PREFETCH = True
-SERIALIZER_CACHE = False
+SERIALIZER_CACHE = True
